/* This is derived from NEWTRACK eyetracking software, (c) 2004 by */
/* Eric Auer. NEWTRACK is free software; you can redistribute it   */
/* and modify it under the terms of the GNU General Public License */
/* as published by the Free Software Foundation; either version 2  */
/* of the License, or (at your option) any later version.          */
/*     NEWTRACK is distributed in the hope that it will be useful, */
/*     but WITHOUT ANY WARRANTY; without even the implied warranty */
/*     of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.     */
/*     See the GNU General Public License for more details.        */
/* You should have received a copy of the GNU General Public       */
/* License (license.txt) along with this program; if not, check    */
/* www.gnu.org or write to the Free Software Foundation, Inc., 59  */
/* Temple Place, Suite 330, Boston, MA  02111-1307 USA.            */

/* common header file for tracker parts */
#ifndef TRACKER_H
#define TRACKER_H

#include <stdio.h>
#include <string.h>
#include <unistd.h>
#include <stdlib.h>	/* exit() */

#include <fcntl.h>	/* open() etc. */
#include <sys/stat.h>	/* file open modes */


#include "arch.h"	/* things to adjust to DJGPP / DOS, for example */


/* Definitions for general use and acquire.c */

#define YESBUTTON 8	/* yes or okay - subject (keyboard alias: y) */
#define NOBUTTON 4	/* no          - subject (keyboard alias: n) */
#define CALBUTTON 2	/* calibrate   - admin   (keyboard alias: c) */
#define NEXTBUTTON 1	/* next item   - admin   (keyboard alias: enter) */
#define ESCBUTTON 16	/* skip trial  - keyboard ESC */
#define ABORTBUTTON 32	/* leave to OS - keyboard ^C or ^D */

#define DEBOUNCE 200	/* default debounce time in milliseconds */

/* acquire.c */

#define TLBBIT 8	/* bit which is 1 while tracking (STATUS PORT) */
#define X_ADCBIT 0x20	/* bit which has X ADC data stream */
#define Y_ADCBIT 0x10	/* bit which has Y ADC data stream */


/* timer.c (uses CPU TimeStampCounter, or DJGPP uclock as fallback) */

uint32 get_ytime (void); /* return low 32 bits of current ysecond uptime */


/* acquire.c (ret. values are all timestamps) */

uint32 get_raw_xy(int * x, int * y); /* return raw x/y coordinates */
    /* values will be in 0..4095 range for 12bit A/D module.       */
    /* x=-1 if A/D readout error happened - used to find the port. */

uint32 get_buttons(int * bits); /* return bitmask: pressed buttons */
    /* low bits are combination of ...BUTTON values defined above. */
    /* If keyboard key, buttons will have key ASCII << 8 and full  */
    /* key << 16 ORed in. */

uint32 debounce(int buttons, int msecs); /* wait until all  of the */
    /* given buttons have stayed unpressed for at least msecs...   */

int get_tracking (void);	/* returns nonzero while tracking  */
    /* tracking -> no blink and tracking not lost. */
    /* replaces "force x of get_raw_xy to -1 while track lost"...  */

#endif
